@@ -3,8 +3,8 @@ from hdx.utilities.dateparse import parse_date
 
 from hdx.scraper.base_scraper import BaseScraper
 from hdx.scraper.outputs.json import JsonFile
-from hdx.scraper.outputs.update_tabs import update_subnational
 from hdx.scraper.runner import Runner
+from hdx.scraper.utilities.writer import Writer
 
 from .conftest import run_check_scraper
 
@@ -85,10 +85,9 @@ class TestScrapersSubnational:
 
         jsonout = JsonFile(configuration["json"], [level])
         outputs = {"json": jsonout}
-        update_subnational(
-            runner,
+        writer = Writer(runner, outputs)
+        writer.update_subnational(
             adminlevel,
-            outputs,
             names=(name,),
         )
         assert jsonout.json[f"{level}_data"] == [
